<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       saleswonder.biz
 * @since      1.0.0
 *
 * @package    Cf7_Customizer
 * @subpackage Cf7_Customizer/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Cf7_Customizer
 * @subpackage Cf7_Customizer/admin
 * @author     Tobias Conrad <tc@saleswonder.biz>
 */
class Cf7_Customizer_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
        if(isset($_GET['page']) && sanitize_text_field($_GET['page']) == 'cf7cstmzr_page') {
            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_style( 'codemirror', plugin_dir_url( __FILE__ ) . 'vendors/codemirror.css', array(), $this->version . time(), 'all' );
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cf7-customizer-admin.css', array(), $this->version . time(), 'all' );
        }
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
        if(isset($_GET['page']) && sanitize_text_field($_GET['page']) == 'cf7cstmzr_page') {
            wp_enqueue_code_editor(array('type' => 'text/css'));

            if ( ! did_action( 'wp_enqueue_media' ) ) {
                wp_enqueue_media();
            }

            wp_enqueue_script( 'codemirror', plugin_dir_url( __FILE__ ) . 'vendors/codemirror.js', array( 'jquery' ), '5.49.2', true );
            wp_enqueue_script( 'jRespond', plugin_dir_url( __FILE__ ) . 'js/jRespond.js', array( 'jquery' ), '0.10', true );
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cf7-customizer-admin.js', array( 'jquery', 'jquery-ui-core', 'wp-color-picker' ), $this->version . time(), true );
        }
	}

	public function settings_page() {
        if (!cf7cstmzr_is_plugin_activated( 'contact-form-7', 'wp-contact-form-7.php' )) {
            add_menu_page(
                __( 'CF7 Styler', 'cf7-styler' ),
                __( 'CF7 Styler', 'cf7-styler' ),
                'administrator',
                'cf7cstmzr_page',
                array($this, 'render_settings_page'),
                'dashicons-email-alt',
                6
            );
        } else {
            add_submenu_page(
                'wpcf7',
                __( 'CF7 Styler', 'cf7-styler' ),
                __( 'CF7 Styler', 'cf7-styler' ),
                'administrator',
                'cf7cstmzr_page',
                array($this, 'render_settings_page')
            );
        }
    }

    public function render_settings_page() {
        include_once CF7CSTMZR_PLUGIN_PATH . 'admin/partials/cf7-customizer-admin-display.php';
    }

    public function check_installation() {
        $style_schemes = get_option('cf7cstmzr_style_schemes', array());

        if (empty($style_schemes)) {
            $default_scheme = array(
                'default' => Cf7_Style_Scheme::get_default_style_scheme()
            );

            update_option('cf7cstmzr_style_schemes', $default_scheme);
        }
    }

    public function rewrite_rule() {
        flush_rewrite_rules();

        add_rewrite_rule('^cf7cstmzr-form-customizer/(.*)/?', 'index.php?cf7cstmzr-form=$matches[1]', 'top');
        add_rewrite_tag( '%cf7cstmzr-form%', '([^&]+)' );
    }

    public function template_redirect() {
	    $form_id = get_query_var( 'cf7cstmzr-form' );

	    if ($form_id) {
            global $content_width;

            if (empty($content_width)) {
                $content_width = 640;
            }

            $form = get_post($form_id);

            get_header();

            if (!empty($form)) {
                ?>
                <div style="max-width: <?php echo $content_width ?>px; margin: auto; padding: 20px;">
                    <?php
                    echo do_shortcode('[contact-form-7 id="'.$form_id.'" title="' . $form->post_title . '"]');
                    ?>
                </div>
                <?php
            }

            get_footer();
	        die;
        }
    }

    public function show_admin_bar() {
        $form_id = get_query_var( 'cf7cstmzr-form' );

        if ($form_id) {
            return false;
        }
    }

    public function admin_body_class($classes) {
        if(isset($_GET['page']) && sanitize_text_field($_GET['page']) == 'cf7cstmzr_page') {
            $classes = $classes . ' cf7cstmzr-body';
        }

	    return $classes;
    }
}
