<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       saleswonder.biz
 * @since      1.0.0
 *
 * @package    Cf7_Customizer
 * @subpackage Cf7_Customizer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Cf7_Customizer
 * @subpackage Cf7_Customizer/public
 * @author     Tobias Conrad <tc@saleswonder.biz>
 */
class Cf7_Customizer_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_Customizer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_Customizer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cf7-customizer-public.css', array(), $this->version, 'all' );

        $form_id = get_query_var( 'cf7cstmzr-form' );
        $plugin_version = Cf7_License::get_license_version();

        if ($form_id) { // Backend testing
            $style_scheme_slug = !empty($_GET['style_scheme']) ? sanitize_text_field($_GET['style_scheme']) : 'default';
            $style_schemes = get_option('cf7cstmzr_style_schemes', array());
            $is_styled = get_option('cf7cstmzr-preview-styled', true);

            if ($is_styled) {
                $temp_styles = get_option('cf7cstmzr_style_schemes_preview', false);

                if (!empty($temp_styles)) {
                    $custom_css = Cf7_Style_Scheme::get_inline_style_scheme($temp_styles, 'preview');

                    delete_option('cf7cstmzr_style_schemes_preview');
                } else {
                    $custom_css = Cf7_Style_Scheme::get_inline_style_scheme($style_schemes, $style_scheme_slug);
                }

                wp_add_inline_style( $this->plugin_name, $custom_css );
            }
        } else { // Frontend use
            $enabled_globally = false;
            $enabled_globally_option = get_option('cf7cstmzr_enabled_globally', false);

            if (!empty($enabled_globally_option)) {

                $enabled_globally = 'default';

                if ('free' !== $plugin_version) {
                    $enabled_globally = $enabled_globally_option;
                }
            }

            $style_schemes = get_option('cf7cstmzr_style_schemes', array());

            if ($enabled_globally) {
                $custom_css = Cf7_Style_Scheme::get_inline_style_scheme($style_schemes, $enabled_globally);

                wp_add_inline_style( $this->plugin_name, $custom_css );
            }

            if ('free' !== $plugin_version) {
                $args = array (
                    'numberposts' => -1,
                    'orderby'     => 'title',
                    'order'       => 'ASC',
                    'post_type'   => 'wpcf7_contact_form',
                    'post_status'   => 'publish',
                    'suppress_filters' => false, // подавление работы фильтров изменения SQL запроса
                    'meta_query' => array(
                        'relation' => 'EXISTS',
                        array(
                            'key' => 'cf7cstmzr_style_scheme',
                        )
                    )
                );

                $cf7_forms = get_posts($args);

                if (!empty($cf7_forms)) {
                    foreach ($cf7_forms as $cf_7_form) {
                        $cf7cstmzr_style_scheme = get_post_meta( $cf_7_form->ID, 'cf7cstmzr_style_scheme', true );

                        $custom_css = Cf7_Style_Scheme::get_inline_style_scheme($style_schemes, $cf7cstmzr_style_scheme, $cf_7_form->ID);
                        wp_add_inline_style( $this->plugin_name, $custom_css );
                    }
                }
            }
        }
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cf7_Customizer_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cf7_Customizer_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cf7-customizer-public.js', array( 'jquery' ), $this->version, false );

	}

	public function add_wrapper($output, $tag, $attr, $m) {
	    if ('contact-form-7' === $tag) {
	        $output_before = '<div id="cf7cstmzr-form" class="cf7cstmzr-form-'.$attr["id"].'">';
	        $output_after = '</div>';

	        $output = $output_before . $output . $output_after;
        }

	    return $output;
    }

}
